@@ -11,7 +11,7 @@
 //! use stacking::stacks::Stack;
 //!
 //! let mut stack: Stack<i32> = Stack::new(0);
-//! stack = stack.push(4);
+//! stack.push(4);
 //! assert_eq!(stack.pop(), Some(4));
 //! ```
 //!
@@ -46,7 +46,7 @@ mod tests {
     #[test]
     fn stack_push_pop() {
         let mut stack: Stack<i32> = Stack::new(0);
-        stack = stack.push(4);
+        stack.push(4);
         assert_eq!(stack.pop(), Some(4));
     }
 
